@@ -2,7 +2,7 @@
 #include "Combinations/RankCombination.h"
 
 using rankResultPtr = void (*const)(std::vector<int>::iterator iter, int n,
-                            int m, double &dblIdx, mpz_t mpzIdx,
+                            int m, double &dblIdx, mpz_class &mpzIdx,
                             const std::vector<int> &Reps);
 
 rankResultPtr GetRankResultFunc(bool IsComb, bool IsMult,
